slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPMonitorConvergedDrawLG

Plots the number of converged eigenvalues at each iteration of the nonlinear eigensolver.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPMonitorConvergedDrawLG(NEP nep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)

Collective on nep

### Input Parameters

| nep | - nonlinear eigensolver context
| its | - iteration number
| its | - iteration number
| nconv | - number of converged eigenpairs so far
| eigr | - real part of the eigenvalues
| eigi | - imaginary part of the eigenvalues
| errest | - error estimates
| nest | - number of error estimates to display
| vf | - viewer and format for monitoring

### Options Database Key

| -nep_monitor_conv draw::draw_lg | - activates NEPMonitorConvergedDrawLG()

### See Also

NEPMonitorSet()

### Level

intermediate

### Location

src/nep/interface/nepmon.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages